<?php
/**
 * Abtheme functions and definitions
 *
 * @package Arctecture
 */

if (!function_exists('arctecture_setup')) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function arctecture_setup()
    {
        // Make theme available for translation.
        load_theme_textdomain('arctecture', get_template_directory() . '/languages');

        // Custom Header
        add_theme_support("custom-header");

        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        // Let WordPress manage the document title.
        add_theme_support('title-tag');

        // Enable support for Post Thumbnails on posts and pages.
        add_theme_support('post-thumbnails');

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'primary' => esc_html__('Primary', 'arctecture'),
        ));

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ));

        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('arctecture_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        // Add support for core custom logo.
        add_theme_support('custom-logo', array(
            'height'      => 250,
            'width'       => 250,
            'flex-width'  => true,
            'flex-height' => true,
        ));
        add_theme_support('post-formats', array(
            'gallery',
            'video',
        ));

        add_theme_support('woocommerce');
        add_theme_support('wc-product-gallery-zoom');
        add_theme_support('wc-product-gallery-lightbox');
        add_theme_support('wc-product-gallery-slider');

        /* Change default image thumbnail sizes in wordpress */
        update_option('thumbnail_size_w', 300);
        update_option('thumbnail_size_h', 300);
        update_option('thumbnail_crop', 1);
        update_option('medium_size_w', 400);
        update_option('medium_size_h', 400);
        update_option('medium_crop', 1);
        update_option('large_size_w', 980);
        update_option('large_size_h', 650);
        update_option('large_crop', 1);

        add_image_size('arctecture-thumbnail', 300, 200, true);

    }
endif;
add_action('after_setup_theme', 'arctecture_setup');

add_action('cms_locations', function ($cms_locations){
//    $cms_locations['cms-test'] ='Test Menu';
    return $cms_locations;
});

add_filter('swa_ie_export_mode', 'arctecture_enable_export_mode');
function arctecture_enable_export_mode()
{
    return false;
}

/*
 *Opimzisi
*/

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function arctecture_content_width()
{
    $GLOBALS['content_width'] = apply_filters('arctecture_content_width', 640);
}

add_action('after_setup_theme', 'arctecture_content_width', 0);

/**
 * Register widget area.
 */
function arctecture_widgets_init()
{
    register_sidebar(array(
        'name'          => esc_html__('Blog Sidebar', 'arctecture'),
        'id'            => 'sidebar-blog',
        'description'   => esc_html__('Add widgets here.', 'arctecture'),
        'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-content">',
        'after_widget'  => '</div></div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Page Sidebar', 'arctecture'),
        'id'            => 'sidebar-page',
        'description'   => esc_html__('Add widgets here.', 'arctecture'),
        'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-content">',
        'after_widget'  => '</div></div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Shop Sidebar', 'arctecture'),
        'id'            => 'sidebar-shop',
        'description'   => esc_html__('Add widgets here.', 'arctecture'),
        'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-content">',
        'after_widget'  => '</div></div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ));

    $footer_top_column = arctecture_get_opt( 'footer_top_column', '4' );
    if(isset($footer_top_column) && $footer_top_column) {

        for($i = 1 ; $i <= $footer_top_column ; $i++){
            register_sidebar(array(
                'name' => sprintf(esc_html__('Footer Top %s', 'arctecture'), $i),
                'id'            => 'sidebar-footer-' . $i,
                'description'   => esc_html__('Add widgets here.', 'arctecture'),
                'before_widget' => '<div id="%1$s" class="widget %2$s">',
                'after_widget'  => '</div>',
                'before_title'  => '<h2 class=" widget-title">',
                'after_title'   => '</h2>',
            ));
        }
    }
    register_sidebar(array(
        'name'          => esc_html__('Footer Social', 'arctecture'),
        'id'            => 'footer-social',
        'description'   => esc_html__('Add widgets here.', 'arctecture'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-content">',
        'after_widget'  => '</div></aside>',
        'before_title'  => '<h2 class="footer-social-title">',
        'after_title'   => '</h2>',
    ));
}

add_action('widgets_init', 'arctecture_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function arctecture_scripts()
{
    $theme = wp_get_theme(get_template());

    wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css', array(), '4.0.0');
    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', array(), '4.7.0');
    wp_enqueue_style('font-material-icon', get_template_directory_uri() . '/assets/css/material-design-iconic-font.min.css', array(), '2.2.0');
    wp_enqueue_style('font-etline-icon', get_template_directory_uri() . '/assets/css/et-line.css', array(), '1.0.0');
    wp_enqueue_style('magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.css', array(), '1.0.0');
    wp_enqueue_style('arctecture-theme', get_template_directory_uri() . '/assets/css/theme.css', array(), $theme->get('Version'));
    wp_enqueue_style('menu', get_template_directory_uri() . '/assets/css/menu.css', array(), $theme->get('Version'));
    wp_enqueue_style('style', get_stylesheet_uri());
    wp_enqueue_style('arctecture-google-fonts', arctecture_fonts_url());

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }

    $sticky_on = arctecture_get_opt('sticky_on', false);
    if ($sticky_on == 1) {
        wp_enqueue_script('headroom', get_template_directory_uri() . '/assets/js/headroom.min.js', array('jquery'), $theme->get('Version'), true);
        wp_enqueue_script('arctecture-headroom', get_template_directory_uri() . '/assets/js/headroom.js', array('jquery'), $theme->get('Version'), true);
    }

    wp_enqueue_script('arctecture-parallax', get_template_directory_uri() . '/assets/js/cms-parallax.js', array( 'jquery' ), '1.0.0', true);
    wp_enqueue_script('match-height', get_template_directory_uri() . '/assets/js/match-height-min.js', array( 'jquery' ), '1.0.0', true);
    wp_enqueue_script('arctecture-sidebar-fixed', get_template_directory_uri() . '/assets/js/sidebar-scroll-fixed.js', array( 'jquery' ), '1.0.0', true);
    wp_enqueue_script('magnific-popup', get_template_directory_uri() . '/assets/js/magnific-popup.min.js', array('jquery'), '1.0.0', true);
    wp_enqueue_script('main', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), $theme->get('Version'), true);
    //wp_enqueue_script('cms-scoll-top', get_template_directory_uri() . '/assets/js/cms-scoll-top.js', array('jquery'), $theme->get('Version'), true);

    wp_register_script('arctecture-carousel', get_template_directory_uri() . '/assets/js/cms-carousel.js', array('jquery'), $theme->get('Version'), true);
    wp_register_script('arctecture-carousel-filter', get_template_directory_uri() . '/assets/js/owl-filter.js', array('jquery'), $theme->get('Version'), true);
    wp_register_script('arctecture-counter-lib', get_template_directory_uri() . '/assets/js/counter.min.js', array('jquery'), $theme->get('Version'), true);
    wp_register_script('arctecture-counter', get_template_directory_uri() . '/assets/js/cms-counter.js', array('jquery'), $theme->get('Version'), true);
}

add_action('wp_enqueue_scripts', 'arctecture_scripts');

/* add editor styles */
function arctecture_add_editor_styles()
{
    add_editor_style('editor-style.css');
}

add_action('admin_init', 'arctecture_add_editor_styles');

/* add admin styles */
function arctecture_admin_style()
{   
    $theme = wp_get_theme(get_template());
    wp_enqueue_style('arctecture-admin-style', get_template_directory_uri() . '/assets/css/admin.css');
    wp_enqueue_style('font-material-icon', get_template_directory_uri() . '/assets/css/material-design-iconic-font.min.css', array(), '2.2.0');
    wp_enqueue_style('font-etline-icon', get_template_directory_uri() . '/assets/css/et-line.css', array(), '1.0.0');
}

add_action('admin_enqueue_scripts', 'arctecture_admin_style');

/* Post like*/
require_once( get_template_directory() . '/inc/post_favorite/post_favorite.php' );

/**
 * Helper functions for this theme.
 */
require_once get_template_directory() . '/inc/template-functions.php';

/**
 * Theme options
 */
require_once get_template_directory() . '/inc/theme-options.php';

/**
 * Page options
 */
require_once get_template_directory() . '/inc/page-options.php';

/**
 * CSS Generator.
 */
if (!class_exists('CSS_Generator')) {
    require_once get_template_directory() . '/inc/classes/class-css-generator.php';
}

/**
 * Breadcrumb.
 */
require_once get_template_directory() . '/inc/classes/class-breadcrumb.php';

/**
 * Custom template tags for this theme.
 */
require_once get_template_directory() . '/inc/template-tags.php';

/* Load list require plugins */
require_once( get_template_directory() . '/inc/require.plugins.php' );

/* Load lib Font */
require_once get_template_directory() . '/inc/libs/fontawesome.php';
require_once get_template_directory() . '/inc/libs/materialdesign.php';
require_once get_template_directory() . '/inc/libs/etline.php';

/**
 * Custom params & remove VC Elements.
 */

function arctecture_vc_after_init()
{

    vc_remove_element("vc_button");
    vc_remove_element("vc_button2");
    vc_remove_element("vc_cta_button");
    vc_remove_element("vc_cta_button2");
    vc_remove_element("vc_cta");
    vc_remove_element("vc_cta");
    vc_remove_element("vc_tabs");
    vc_remove_element("vc_tour");
    vc_remove_element("vc_accordion");
    require_once ( get_template_directory() . '/vc_elements/cms_custom_vc_pagram.php' );

}

add_action('vc_after_init', 'arctecture_vc_after_init');

/**
 * Add new elements for VC
 */
function arctecture_vc_elements()
{

    if (class_exists('CmsShortCode')) {

        cms_require_folder('vc_elements', get_template_directory());
    }
}

add_action('vc_after_init', 'arctecture_vc_elements');

/**
 * Additional widgets for the theme
 */
require_once get_template_directory() . '/widgets/widget-recent-post.php';
require_once get_template_directory() . '/widgets/widget-recent-project.php';
require_once get_template_directory() . '/widgets/widget-social.php';
require_once get_template_directory() . '/widgets/widget-gtouch.php';
require_once get_template_directory() . '/widgets/widget-gtouch2.php';
require_once get_template_directory() . '/widgets/widget-gtouch3.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require_once get_template_directory() . '/inc/extends.php';


/**
 * Tutorials snippet functions. You should add those to extends.php
 * and remove the file.
 */
require_once get_template_directory() . '/inc/snippets.php';

/**
 * Add custom class in Row Visual Composer
 */
function arctecture_vc_shortcode_css_class( $classes, $settings_base, $atts )
{
    $classes_arr = explode( ' ', $classes );

    if ( 'vc_row' == $settings_base ) {
        if ( $atts['cms_row_class'] ) {
            $classes_arr[] = $atts['cms_row_class'];
        }
    }
    if ( 'vc_column' == $settings_base ) {
        if ( $atts['cms_column_class'] ) {
            $classes_arr[] = $atts['cms_column_class'];
        }
    }

    if ( 'vc_column' == $settings_base ) {
        if ( $atts['cms_column_offset'] ) {
            $classes_arr[] = $atts['cms_column_offset'];
        }
    }

    if ( isset($atts['animation_column']) && $atts['animation_column'] ) {
        wp_enqueue_script( 'waypoints' );
        wp_enqueue_style( 'animate-css' );
        $classes_arr[] = 'wpb_animate_when_almost_visible '.' wpb_'.$atts['animation_column'].' '.$atts['animation_column'];
    }

    if ( 'vc_column_inner' == $settings_base ) {
        if ( $atts['cms_column_inner_class'] ) {
            $classes_arr[] = $atts['cms_column_inner_class'];
        }
    }

    return implode( ' ', $classes_arr );
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    add_filter( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, 'arctecture_vc_shortcode_css_class', 10, 3 );
}

/**
 * arctecture_hide_page_title
 *
 * Removes the "shop" title on the main shop page
 *
 * @access      public
 * @since       1.0
 * @return      void
 */
function arctecture_hide_page_title()
{
    return false;
}

add_filter('woocommerce_show_page_title', 'arctecture_hide_page_title');

/**
 * Custom post types and args based on plugin.
 * require plugin
 */
add_filter('arctecture_extra_post_types', 'arctecture_extra_post_types_func_1' );
function arctecture_extra_post_types_func_1($post_types)
{
    return array('portfolio' => true, 'team_member' => true);
}

add_filter('arctecture_extra_post_types', 'arctecture_extra_post_types_func_2');
function cmssuperheroes_extra_post_types_func_2($args) {
    $args['labels']['menu_name'] = 'Portfolio Test Filter';
    return $args;
}

if ( ! function_exists( 'arctecture_fonts_url' ) ) :
    /**
     * Register Google fonts for architecture.
     *
     * Create your own arctecture_fonts_url() function to override in a child theme.
     *
     * @since league 1.1
     *
     * @return string Google fonts URL for the theme.
     */
    function arctecture_fonts_url()
    {
        $fonts_url = '';
        $fonts     = array();
        $subsets   = 'latin,latin-ext';

        if ( 'off' !== _x( 'on', 'Poppins font: on or off', 'arctecture' ) )
        {
            $fonts[] = 'Poppins:300,400,500,600,700,800,900';
        }

        if ( 'off' !== _x( 'on', 'Montserrat font: on or off', 'arctecture' ) )
        {
            $fonts[] = 'Montserrat:200,300,400,500,600,700,800';
        }

        if ( 'off' !== _x( 'on', 'Playfair+Display+SC font: on or off', 'arctecture' ) )
        {
            $fonts[] = 'Playfair+Display+SC:400,700';
        }


        if ( $fonts ) {
            $fonts_url = add_query_arg( array(
                'family' => urlencode( implode( '|', $fonts ) ),
                'subset' => urlencode( $subsets ),
            ), 'https://fonts.googleapis.com/css' );
        }

        return $fonts_url;
    }
endif;


/**
 * Add Template Woocommerce
 */
if(class_exists('Woocommerce')){
    add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 9;' ), 3 );
    require_once( get_template_directory() . '/woocommerce/wc-function-hooks.php' );
}

/**
 * Commnet Form
 */
function arctecture_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter( 'comment_form_fields', 'arctecture_comment_field_to_bottom' );

/**
 * User custom fields.
 */
add_action( 'show_user_profile', 'arctecture_user_fields' );
add_action( 'edit_user_profile', 'arctecture_user_fields' );
function arctecture_user_fields($user){

    $user_facebook = get_user_meta($user->ID, 'user_facebook', true);
    $user_twitter = get_user_meta($user->ID, 'user_twitter', true);
    $user_linkedin = get_user_meta($user->ID, 'user_linkedin', true);
    $user_skype = get_user_meta($user->ID, 'user_skype', true);
    $user_google = get_user_meta($user->ID, 'user_google', true);
    $user_youtube = get_user_meta($user->ID, 'user_youtube', true);
    $user_vimeo = get_user_meta($user->ID, 'user_vimeo', true);
    $user_tumblr = get_user_meta($user->ID, 'user_tumblr', true);
    $user_rss = get_user_meta($user->ID, 'user_rss', true);
    $user_pinterest = get_user_meta($user->ID, 'user_pinterest', true);
    $user_instagram = get_user_meta($user->ID, 'user_instagram', true);
    $user_yelp = get_user_meta($user->ID, 'user_yelp', true);

    ?>
    <h3><?php esc_html_e('Social', 'arctecture'); ?></h3>
    <table class="form-table">
        <tr>
            <th><label for="user_facebook"><?php esc_html_e('Facebook', 'arctecture'); ?></label></th>
            <td>
                <input id="user_facebook" name="user_facebook" type="text" value="<?php echo esc_attr(isset($user_facebook) ? $user_facebook : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_twitter"><?php esc_html_e('Twitter', 'arctecture'); ?></label></th>
            <td>
                <input id="user_twitter" name="user_twitter" type="text" value="<?php echo esc_attr(isset($user_twitter) ? $user_twitter : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_linkedin"><?php esc_html_e('Linkedin', 'arctecture'); ?></label></th>
            <td>
                <input id="user_linkedin" name="user_linkedin" type="text" value="<?php echo esc_attr(isset($user_linkedin) ? $user_linkedin : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_skype"><?php esc_html_e('Skype', 'arctecture'); ?></label></th>
            <td>
                <input id="user_skype" name="user_skype" type="text" value="<?php echo esc_attr(isset($user_skype) ? $user_skype : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_google"><?php esc_html_e('Google', 'arctecture'); ?></label></th>
            <td>
                <input id="user_google" name="user_google" type="text" value="<?php echo esc_attr(isset($user_google) ? $user_google : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_youtube"><?php esc_html_e('Youtube', 'arctecture'); ?></label></th>
            <td>
                <input id="user_youtube" name="user_youtube" type="text" value="<?php echo esc_attr(isset($user_youtube) ? $user_youtube : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_vimeo"><?php esc_html_e('Vimeo', 'arctecture'); ?></label></th>
            <td>
                <input id="user_vimeo" name="user_vimeo" type="text" value="<?php echo esc_attr(isset($user_vimeo) ? $user_vimeo : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_tumblr"><?php esc_html_e('Tumblr', 'arctecture'); ?></label></th>
            <td>
                <input id="user_tumblr" name="user_tumblr" type="text" value="<?php echo esc_attr(isset($user_tumblr) ? $user_tumblr : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_rss"><?php esc_html_e('Rss', 'arctecture'); ?></label></th>
            <td>
                <input id="user_rss" name="user_rss" type="text" value="<?php echo esc_attr(isset($user_rss) ? $user_rss : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_pinterest"><?php esc_html_e('Pinterest', 'arctecture'); ?></label></th>
            <td>
                <input id="user_pinterest" name="user_pinterest" type="text" value="<?php echo esc_attr(isset($user_pinterest) ? $user_pinterest : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_instagram"><?php esc_html_e('Instagram', 'arctecture'); ?></label></th>
            <td>
                <input id="user_instagram" name="user_instagram" type="text" value="<?php echo esc_attr(isset($user_instagram) ? $user_instagram : ''); ?>" />
            </td>
        </tr>
        <tr>
            <th><label for="user_yelp"><?php esc_html_e('Yelp', 'arctecture'); ?></label></th>
            <td>
                <input id="user_yelp" name="user_yelp" type="text" value="<?php echo esc_attr(isset($user_yelp) ? $user_yelp : ''); ?>" />
            </td>
        </tr>
    </table>
    <?php
}

/**
 * Save user custom fields.
 */
add_action( 'personal_options_update', 'arctecture_save_user_custom_fields' );
add_action( 'edit_user_profile_update', 'arctecture_save_user_custom_fields' );
function arctecture_save_user_custom_fields( $user_id )
{
    if ( !current_user_can( 'edit_user', $user_id ) )
        return false;

    if(isset($_POST['user_facebook']))
        update_user_meta( $user_id, 'user_facebook', $_POST['user_facebook'] );
    if(isset($_POST['user_twitter']))
        update_user_meta( $user_id, 'user_twitter', $_POST['user_twitter'] );
    if(isset($_POST['user_linkedin']))
        update_user_meta( $user_id, 'user_linkedin', $_POST['user_linkedin'] );
    if(isset($_POST['user_skype']))
        update_user_meta( $user_id, 'user_skype', $_POST['user_skype'] );
    if(isset($_POST['user_google']))
        update_user_meta( $user_id, 'user_google', $_POST['user_google'] );
    if(isset($_POST['user_youtube']))
        update_user_meta( $user_id, 'user_youtube', $_POST['user_youtube'] );
    if(isset($_POST['user_vimeo']))
        update_user_meta( $user_id, 'user_vimeo', $_POST['user_vimeo'] );
    if(isset($_POST['user_tumblr']))
        update_user_meta( $user_id, 'user_tumblr', $_POST['user_tumblr'] );
    if(isset($_POST['user_rss']))
        update_user_meta( $user_id, 'user_rss', $_POST['user_rss'] );
    if(isset($_POST['user_pinterest']))
        update_user_meta( $user_id, 'user_pinterest', $_POST['user_pinterest'] );
    if(isset($_POST['user_instagram']))
        update_user_meta( $user_id, 'user_instagram', $_POST['user_instagram'] );
    if(isset($_POST['user_yelp']))
        update_user_meta( $user_id, 'user_yelp', $_POST['user_yelp'] );
}

add_filter('cms_documentation_link',function(){
     return 'http://doc.farost.net/arctecture';
});

add_filter('cms_ticket_link', 'arctecture_add_cms_ticket_link');
function arctecture_add_cms_ticket_link($url)
{
    $url = array('type' => 'email', 'link' => 'farost.agency@gmail.com');
    return $url;
}
add_filter('cms_video_tutorial_link',function(){
     return 'https://www.youtube.com/playlist?list=PLOfHiKVRFyOV5epXDVS-ExwGraAyV4H59';
});