<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Arctecture
 */

/**
 * Setup default image sizes after the theme has been activated
 */
function arctecture_after_setup_theme()
{

}
add_action( 'after_setup_theme', 'arctecture_after_setup_theme' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function arctecture_body_classes( $classes )
{

    $header_layout = arctecture_get_opt( 'header_layout', '3' );
    $custom_header = arctecture_get_page_opt( 'custom_header', '0' );
    if ( is_page() && $custom_header == '1' )
    {
        $page_header_layout = arctecture_get_page_opt('header_layout');
        $header_layout = $page_header_layout;
    }
    $classes[] = 'header-'.$header_layout;

    // Adds a class of group-blog to blogs with more than 1 published author.
    if (is_multi_author()) {
        $classes[] = 'group-blog';
    }

    // Adds a class of hfeed to non-singular pages.
    if (!is_singular()) {
        $classes[] = 'hfeed';
    }

    if (arctecture_get_opt( 'site_boxed', false )) {
        $classes[] = 'site-boxed';
    }

    if ( class_exists('WPBakeryVisualComposerAbstract') ) {
        $classes[] = 'visual-composer';
    }

    return $classes;
}
add_filter( 'body_class', 'arctecture_body_classes' );


/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function arctecture_pingback_header()
{
    if ( is_singular() && pings_open() )
    {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'arctecture_pingback_header' );
