<?php
/**
 * Register metabox for posts based on Redux Framework. Supported methods:
 *     isset_args( $post_type )
 *     set_args( $post_type, $redux_args, $metabox_args )
 *     add_section( $post_type, $sections )
 * Each post type can contains only one metabox. Pease note that each field id
 * leads by an underscore sign ( _ ) in order to not show that into Custom Field
 * Metabox from WordPress core feature.
 *
 * @param  arctecture_Post_Metabox $metabox
 */

function arctecture_page_options_register($metabox)
{

    if (!$metabox->isset_args('page')) {
        $metabox->set_args('page', array(
            'opt_name'     => arctecture_get_page_opt_name(),
            'display_name' => esc_html__('Page Settings', 'arctecture'),
            'show_options_object' => true,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    if (!$metabox->isset_args('cms_pf_audio')) {
        $metabox->set_args('cms_pf_audio', array(
            'opt_name'     => 'post_format_audio',
            'display_name' => esc_html__('Audio', 'arctecture'),
            'class' => 'fully-expanded',
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    if (!$metabox->isset_args('cms_pf_link')) {
        $metabox->set_args('cms_pf_link', array(
            'opt_name'     => 'post_format_link',
            'display_name' => esc_html__('Link', 'arctecture')
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    if (!$metabox->isset_args('cms_pf_quote')) {
        $metabox->set_args('cms_pf_quote', array(
            'opt_name'     => 'post_format_quote',
            'display_name' => esc_html__('Quote', 'arctecture')
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    if (!$metabox->isset_args('cms_pf_video')) {
        $metabox->set_args('cms_pf_video', array(
            'opt_name'     => 'post_format_video',
            'display_name' => esc_html__('Video', 'arctecture'),
            'class' => 'fully-expanded',
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    if (!$metabox->isset_args('cms_pf_gallery')) {
        $metabox->set_args('cms_pf_gallery', array(
            'opt_name'     => 'post_format_gallery',
            'display_name' => esc_html__('Gallery', 'arctecture'),
            'class' => 'fully-expanded',
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    if (!$metabox->isset_args('post')) {
        $metabox->set_args('post', array(
            'opt_name'     => 'post_option',
            'display_name' => esc_html__('Post Settings', 'arctecture'),
            'show_options_object' => true,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    if (!$metabox->isset_args('gallerie')) {
        $metabox->set_args('gallerie', array(
            'opt_name'     => 'gallrie_option',
            'display_name' => esc_html__('Gallery Settings', 'arctecture'),
            'show_options_object' => true,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    if (!$metabox->isset_args('portfolio')) {
        $metabox->set_args('portfolio', array(
            'opt_name'     => 'portfolio_option',
            'display_name' => esc_html__('Portfolio Settings', 'arctecture'),
            'show_options_object' => true,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    if (!$metabox->isset_args('service')) {
        $metabox->set_args('service', array(
            'opt_name'     => 'service_option',
            'display_name' => esc_html__('Services Settings', 'arctecture'),
            'show_options_object' => true,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ));
    }

    /**
     * Config post meta options
     *
     */

    $metabox->add_section('post', array(
        'title'  => esc_html__('Sidebar Position', 'arctecture'),
        'icon'   => 'el el-refresh',
        'fields' => array(
            array(
                'id'       => 'custom_pagetitle',
                'type'     => 'switch',
                'title'    => esc_html__('Custom Page Title', 'arctecture'),
                'default'  => false,
                'indent' => true
            ),
            array(
                'id'       => 'ptitle_layout',
                'type'     => 'image_select',
                'title'    => esc_html__('Layout', 'arctecture'),
                'subtitle' => esc_html__('Select a layout for page title.', 'arctecture'),
                'options'  => array(
                    '0' => get_template_directory_uri() . '/assets/images/page-title-layout/p0.jpg',
                    '1' => get_template_directory_uri() . '/assets/images/page-title-layout/p1.jpg',
                ),
                'default'  => arctecture_get_option_of_theme_options('ptitle_layout'),
                'required' => array( 0 => 'custom_pagetitle', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'       => 'custom_sidebar_post',
                'type'     => 'switch',
                'title'    => esc_html__('Custom Sidebar Position', 'arctecture'),
                'default'  => false,
                'indent' => true
            ),
            array(
                'id'       => 'sidebar_post_pos',
                'type'     => 'button_set',
                'title'    => esc_html__('Sidebar Position', 'arctecture'),
                'options'  => array(
                    'left'  => esc_html__('Left', 'arctecture'),
                    'right' => esc_html__('Right', 'arctecture'),
                    'none'  => esc_html__('Disabled', 'arctecture')
                ),
                'default'  => 'right',
                'required' => array( 0 => 'custom_sidebar_post', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'          => 'post-gallery-images2',
                'type'        => 'gallery',
                'title'       => esc_html__('Gallery Images Bottom', 'arctecture'),
                'subtitle'    => esc_html__('Upload images or add from media library.', 'arctecture')
            ),
        )
    ));

    /**
     * Config portfolio meta options
     *
     */
    $metabox->add_section('portfolio', array(
        'title'  => esc_html__('Page Title', 'arctecture'),
        'desc'   => esc_html__('Settings for page title.', 'arctecture'),
        'icon'   => 'el-icon-map-marker',
        'fields' => array(
            array(
                'id'       => 'custom_pagetitle',
                'type'     => 'switch',
                'title'    => esc_html__('Custom Page Title', 'arctecture'),
                'default'  => false,
                'indent' => true
            ),
            array(
                'id'       => 'ptitle_layout',
                'type'     => 'image_select',
                'title'    => esc_html__('Layout', 'arctecture'),
                'subtitle' => esc_html__('Select a layout for page title.', 'arctecture'),
                'options'  => array(
                    '0' => get_template_directory_uri() . '/assets/images/page-title-layout/p0.jpg',
                    '1' => get_template_directory_uri() . '/assets/images/page-title-layout/p1.jpg',
                ),
                'default'  => arctecture_get_option_of_theme_options('ptitle_layout'),
                'required' => array( 0 => 'custom_pagetitle', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),

            array(
                'id'      => 'ptitle_off',
                'type'    => 'switch',
                'title'   => esc_html__('Hidden Title', 'arctecture'),
                'default' => false,
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'      => 'breadcrumb_on',
                'type'    => 'switch',
                'title'   => esc_html__('Breadcrumb', 'arctecture'),
                'default' => true,
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
        )
    ));
   $metabox->add_section('portfolio', array(
        'title'  => esc_html__('Gallery Images', 'arctecture'),
        'desc'   => esc_html__('Portfolio Gallery', 'arctecture'),
        'icon'   => 'el-icon-map-marker',
        'fields' => array(
            array(
                'id'          => 'portfolio-gallery-images',
                'type'        => 'gallery',
                'title'       => esc_html__('Gallery Images', 'arctecture'),
                'subtitle'    => esc_html__('Upload images or add from media library.', 'arctecture')
            ),
        )
    ));
   $metabox->add_section('portfolio', array(
        'title'  => esc_html__('Short info', 'arctecture'),
        'desc'   => esc_html__('Short info', 'arctecture'),
        'icon'   => 'el-icon-map-marker',
        'fields' => array(
            array(
                'id'       => 'sub_port_title',
                'type'     => 'text',
                'title'    => esc_html__('Sub Title', 'arctecture'),
                'subtitle' => esc_html__('Sub Title for Portfolio Single', 'arctecture'),
                // 'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                // 'force_output' => true
            ),
            array(
                'id'       => 'text_port_11',
                'type'     => 'text',
                'title'    => esc_html__('Title Box1', 'arctecture'),
            ),
            array(
                'id'       => 'text_port_12',
                'type'     => 'text',
                'title'    => esc_html__('Sub 1', 'arctecture'),
            ),
            array(
                'id'       => 'text_port_21',
                'type'     => 'text',
                'title'    => esc_html__('Title Box2', 'arctecture'),
            ),
            array(
                'id'       => 'text_port_22',
                'type'     => 'text',
                'title'    => esc_html__('Sub 2', 'arctecture'),
            ),
            array(
                'id'       => 'text_port_31',
                'type'     => 'text',
                'title'    => esc_html__('Title Box3', 'arctecture'),
            ),
            array(
                'id'       => 'text_port_32',
                'type'     => 'text',
                'title'    => esc_html__('Sub 3', 'arctecture'),
            ),
            array(
                'id'       => 'text_port_41',
                'type'     => 'text',
                'title'    => esc_html__('Title Box4', 'arctecture'),
            ),
            array(
                'id'       => 'text_port_42',
                'type'     => 'text',
                'title'    => esc_html__('Sub 4', 'arctecture'),
            ),
            array(
                'id'       => 'text_port_excerpt',
                'type'     => 'textarea',
                'title'    => esc_html__('Portfolio Excerpt', 'arctecture'),
            ),
        )
    ));

    /**
     * Config page meta options
     *
     */
    $metabox->add_section('page', array(
        'title'  => esc_html__('Header', 'arctecture'),
        'desc'   => esc_html__('Header settings for the page.', 'arctecture'),
        'icon'   => 'el-icon-website',
        'fields' => array(
            array(
                'id'       => 'custom_header',
                'type'     => 'switch',
                'title'    => esc_html__('Custom Header', 'arctecture'),
                'default'  => false,
                'indent' => true
            ),
            array(
                'id'       => 'header_layout',
                'type'     => 'image_select',
                'title'    => esc_html__('Layout', 'arctecture'),
                'subtitle' => esc_html__('Select a layout for header.', 'arctecture'),
                'options'  => array(
                    '1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
                    '2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
                ),
                'default'  => arctecture_get_option_of_theme_options('header_layout'),
                'required' => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'       => 'bg_topbar',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Background Topbar', 'arctecture'),
                'subtitle' => esc_html__('Select background-color for Topbar section.', 'arctecture'),
                'output' => array('background-color' => '.topbar-panel')
            ),
            array(
                'id'       => 'bg_logo_menu',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Background Logo & Menu', 'arctecture'),
                'subtitle' => esc_html__('Select background color for Logo & Menu section.', 'arctecture'),
                'output' => array('background-color' => 'body #site-header-wrap #headroom.site-header-main')
            ),
        )
    ));

    $metabox->add_section('page', array(
        'title'  => esc_html__('Page Title', 'arctecture'),
        'desc'   => esc_html__('Settings for page title.', 'arctecture'),
        'icon'   => 'el-icon-map-marker',
        'fields' => array(
            array(
                'id'       => 'custom_pagetitle',
                'type'     => 'switch',
                'title'    => esc_html__('Custom Page Title', 'arctecture'),
                'default'  => false,
                'indent' => true
            ),
            array(
                'id'       => 'ptitle_layout',
                'type'     => 'image_select',
                'title'    => esc_html__('Layout', 'arctecture'),
                'subtitle' => esc_html__('Select a layout for page title.', 'arctecture'),
                'options'  => array(
                    '0' => get_template_directory_uri() . '/assets/images/page-title-layout/p0.jpg',
                    '1' => get_template_directory_uri() . '/assets/images/page-title-layout/p1.jpg',
                ),
                'default'  => arctecture_get_option_of_theme_options('ptitle_layout'),
                'required' => array( 0 => 'custom_pagetitle', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'       => 'custom_title',
                'type'     => 'text',
                'title'    => esc_html__('Custom Title', 'arctecture'),
                'subtitle' => esc_html__('Use custom title for this page. The default title will be used on document title.', 'arctecture'),
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'       => 'subpage_title',
                'type'     => 'text',
                'title'    => esc_html__('Sub Title', 'arctecture'),
                'subtitle' => esc_html__('Sub Title for this page', 'arctecture'),
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'       => 'ptitle_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background Image', 'arctecture'),
                'subtitle' => esc_html__('Upload images or add from media library.', 'arctecture'),
                'output'   => array('#pagetitle'),
                'background-color'   => false,
                'background-repeat'   => false,
                'background-position'   => false,
                'background-attachment'   => false,
                'background-size'   => false,
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'       => 'title_padding',
                'type'     => 'spacing',
                'title'    => esc_html__('Paddings', 'arctecture'),
                'subtitle' => esc_html__('Paddings Top & Bottom of page.', 'arctecture'),
                'output'   => array('#pagetitle'),
                'mode'     => 'padding',
                'units'    => array('px'),
                'right'    => false,
                'left'     => false,
                'default'  => array(
                    'padding-top'    => '',
                    'padding-bottom' => ''
                ),
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'      => 'breadcrumb_on',
                'type'    => 'switch',
                'title'   => esc_html__('Breadcrumb', 'arctecture'),
                'default' => true,
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
        )
    ));

    $metabox->add_section('page', array(
        'title'  => esc_html__('Content', 'arctecture'),
        'desc'   => esc_html__('Settings for content area.', 'arctecture'),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id'       => 'content_bg_color',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Background Color', 'arctecture'),
                'subtitle' => esc_html__('Content background color.', 'arctecture'),
                'output' => array('background-color' => '#content')
            ),
            array(
                'id'             => 'content_padding',
                'type'           => 'spacing',
                'output'         => array('#content'),
                'right'   => false,
                'left'    => false,
                'mode'           => 'padding',
                'units'          => array('px'),
                'units_extended' => 'false',
                'title'          => esc_html__('Content Padding', 'arctecture'),
                'desc'           => esc_html__('Default: Top-90px, Bottom-90px', 'arctecture'),
                'default'            => array(
                    'padding-top'   => '',  
                    'padding-bottom'   => '',  
                    'units'          => 'px', 
                )
            ),
            array(
                'id'       => 'show_sidebar_page',
                'type'     => 'switch',
                'title'    => esc_html__('Show Sidebar', 'arctecture'),
                'default'  => false,
                'indent' => true
            ),
            array(
                'id'       => 'sidebar_page_pos',
                'type'     => 'button_set',
                'title'    => esc_html__('Sidebar Position', 'arctecture'),
                'options'  => array(
                    'left'  => esc_html__('Left', 'arctecture'),
                    'right' => esc_html__('Right', 'arctecture'),
                ),
                'default'  => 'right',
                'required' => array( 0 => 'show_sidebar_page', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
        )
    ));

    $metabox->add_section('page', array(
        'title'  => esc_html__('Footer', 'arctecture'),
        'desc'   => esc_html__('Settings for page footer.', 'arctecture'),
        'icon'   => 'el el-website',
        'fields' => array(
            array(
                'id'       => 'custom_footer',
                'type'     => 'switch',
                'title'    => esc_html__('Custom Footer', 'arctecture'),
                'default'  => false,
                'indent' => true
            ),
            array(
                'id'       => 'footer_layout',
                'type'     => 'image_select',
                'title'    => esc_html__('Layout', 'arctecture'),
                'subtitle' => esc_html__('Select a layout for upper footer area.', 'arctecture'),
                'options'  => array(
                    '0' => get_template_directory_uri() . '/assets/images/footer-layout/f0.jpg',
                    '1' => get_template_directory_uri() . '/assets/images/footer-layout/f1.jpg',
                    '2' => get_template_directory_uri() . '/assets/images/footer-layout/f2.jpg'
                ),
                'default'  => arctecture_get_option_of_theme_options('footer_layout'),
                'required' => array( 0 => 'custom_footer', 1 => '=', 2 => '1' ),
                'force_output' => true
            ))
    ));

    /**
     * Config post format meta options
     *
     */

    $metabox->add_section('cms_pf_video', array(
        'title'  => esc_html__('Video', 'arctecture'),
        'fields' => array(
            array(
                'id'        => 'post-video-url',
                'type'      => 'text',
                'title'     => esc_html__( 'Video URL', 'arctecture' ),
                'desc'  => esc_html__( 'YouTube or Vimeo video URL', 'arctecture' )
            ),

            array(
                'id'        => 'post-video-file',
                'type'      => 'editor',
                'title'     => esc_html__( 'Video Upload', 'arctecture' ),
                'desc'  => esc_html__( 'Upload video file', 'arctecture' )
            ),

            array(
                'id'        => 'post-video-html',
                'type'      => 'textarea',
                'title'     => esc_html__( 'Embadded video', 'arctecture' ),
                'desc'  => esc_html__( 'Use this option when the video does not come from YouTube or Vimeo', 'arctecture' )
            )
        )
    ));

    $metabox->add_section('cms_pf_gallery', array(
        'title'  => esc_html__('Gallery', 'arctecture'),
        'fields' => array(
            array(
                'id'       => 'post-gallery-lightbox',
                'type'     => 'switch',
                'title'    => esc_html__('Lightbox?', 'arctecture'),
                'subtitle' => esc_html__('Enable lightbox for gallery images.', 'arctecture'),
                'default'  => true
            ),
            array(
                'id'          => 'post-gallery-images',
                'type'        => 'gallery',
                'title'       => esc_html__('Gallery Images ', 'arctecture'),
                'subtitle'    => esc_html__('Upload images or add from media library.', 'arctecture')
            ),
        )
    ));

    $metabox->add_section('cms_pf_audio', array(
        'title'  => esc_html__('Audio', 'arctecture'),
        'fields' => array(
            array(
                'id'       => 'post-audio-url',
                'type'     => 'text',
                'title'    => esc_html__('Audio URL', 'arctecture'),
                'description' => esc_html__('Audio file URL in format: mp3, ogg, wav.', 'arctecture'),
                'validate' => 'url',
                'msg'      => 'Url error!'
            )
        )
    ));

    $metabox->add_section('cms_pf_link', array(
        'title'  => esc_html__('Link', 'arctecture'),
        'fields' => array(
            array(
                'id'       => 'post-link-url',
                'type'     => 'text',
                'title'    => esc_html__('URL', 'arctecture'),
                'validate' => 'url',
                'msg'      => 'Url error!'
            )
        )
    ));

    $metabox->add_section('cms_pf_quote', array(
        'title'  => esc_html__('Quote', 'arctecture'),
        'fields' => array(
            array(
                'id'       => 'post-quote-cite',
                'type'     => 'text',
                'title'    => esc_html__('Cite', 'arctecture')
            )
        )
    ));


    /**
     * Config gallery meta options
     *
     */
    $metabox->add_section('gallerie', array(
        'title'  => esc_html__('Grid Column', 'arctecture'),
        'icon'   => 'el-icon-website',
        'fields' => array(
            array(
                'id'       => 'el_col_xs',
                'type'     => 'select',
                'title'    => esc_html__('Column XS', 'arctecture'),
                'subtitle'    => esc_html__('575px < Devices < 767px', 'arctecture'),  
                'options'  => array(
                    '' => 'Default',
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'el_col_sm',
                'type'     => 'select',
                'title'    => esc_html__('Column SM', 'arctecture'), 
                'subtitle'    => esc_html__('575px < Devices < 767px', 'arctecture'), 
                'options'  => array(
                    '' => 'Default',
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'el_col_md',
                'type'     => 'select',
                'title'    => esc_html__('Column MD', 'arctecture'), 
                'subtitle'    => esc_html__('768px < Devices < 991px', 'arctecture'), 
                'options'  => array(
                    '' => 'Default',
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'el_col_lg',
                'type'     => 'select',
                'title'    => esc_html__('Column LG', 'arctecture'), 
                'subtitle'    => esc_html__('Devices > 1200px', 'arctecture'), 
                'options'  => array(
                    '' => 'Default',
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                ),
                'default'  => '',
            ),
        )
    ));

    /**
     * Config service meta options
     *
     */
    $metabox->add_section('service', array(
        'title'  => esc_html__('Page Title', 'arctecture'),
        'desc'   => esc_html__('Settings for page title.', 'arctecture'),
        'icon'   => 'el-icon-map-marker',
        'fields' => array(
            array(
                'id'       => 'custom_pagetitle',
                'type'     => 'switch',
                'title'    => esc_html__('Custom Page Title', 'arctecture'),
                'default'  => false,
                'indent' => true
            ),
            array(
                'id'       => 'ptitle_layout',
                'type'     => 'image_select',
                'title'    => esc_html__('Layout', 'arctecture'),
                'subtitle' => esc_html__('Select a layout for page title.', 'arctecture'),
                'options'  => array(
                    '0' => get_template_directory_uri() . '/assets/images/page-title-layout/p0.jpg',
                    '1' => get_template_directory_uri() . '/assets/images/page-title-layout/p1.jpg',
                ),
                'default'  => arctecture_get_option_of_theme_options('ptitle_layout'),
                'required' => array( 0 => 'custom_pagetitle', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),

            array(
                'id'      => 'ptitle_off',
                'type'    => 'switch',
                'title'   => esc_html__('Hidden Title', 'arctecture'),
                'default' => false,
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),

            array(
                'id'       => 'service_ptitle_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background', 'arctecture'),
                'subtitle' => esc_html__('Page title background.', 'arctecture'),
                'output'   => array('.single-service #pagetitle'),
                'background-color'   => false,
                'background-repeat'   => false,
                'background-position'   => false,
                'background-attachment'   => false,
                'background-size'   => false,
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'      => 'breadcrumb_on',
                'type'    => 'switch',
                'title'   => esc_html__('Breadcrumb', 'arctecture'),
                'default' => false,
                'required' => array( 0 => 'ptitle_layout', 1 => '=', 2 => '1' ),
                'force_output' => true
            ),
        )
    ));
    $metabox->add_section('service', array(
        'title'  => esc_html__('Content Meta', 'arctecture'),
        'desc'   => esc_html__('Settings for page title.', 'arctecture'),
        'icon'   => 'el-icon-map-marker',
        'fields' => array(
            array(
                'id'       => 'ptitle_meta',
                'type'     => 'text',
                'title'    => esc_html__('Custom Title', 'arctecture'),
                'subtitle' => esc_html__('Use custom title for this page. The default title will be used on document title.', 'arctecture'),
            ),
            array(
                'id'=>'service_excerpt',
                'type' => 'textarea',
                'title' => esc_html__('Excerpt', 'arctecture'),
                'validate' => 'html_custom',
                'default' => '',
                'allowed_html' => array(
                    'a' => array(
                        'href' => array(),
                        'title' => array()
                    ),
                    'br' => array(),
                    'em' => array(),
                    'strong' => array(),
                    'div' => array(),
                ),
            ),
            array(
                'id'       => 'icon_head_deer',
                'type'     => 'media',
                'title'    => esc_html__('Image Transparent', 'arctecture'),
                 'default' => array(
                    'url'=>get_template_directory_uri().'/assets/images/head-deer.png'
                ),
            ),
            array(
                'id'       => 'icon_image',
                'type'     => 'media',
                'title'    => esc_html__('Icon Image', 'arctecture'),
                'default' => array(
                    'url'=>get_template_directory_uri().'/assets/images/service-icon.png'
                ),
            )
        )
    ));
}


add_action('cms_post_metabox_register', 'arctecture_page_options_register');

function arctecture_get_option_of_theme_options($key, $default = '')
{
    if (empty($key)) return '';
    $options = get_option(arctecture_get_opt_name(), array());
    $value = isset($options[$key]) ? $options[$key] : $default;
    return $value;
}