<?php
if (!class_exists('ReduxFramework')) {
    return;
}
if (class_exists('ReduxFrameworkPlugin')) {
    remove_filter('plugin_row_meta', array(ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);
    remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
}

$opt_name = arctecture_get_opt_name();
$theme = wp_get_theme();

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version'      => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type'            => class_exists('CmssuperheroesCore') ? 'submenu' : '',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => esc_html__('Theme Options', 'arctecture'),
    'page_title'           => esc_html__('Theme Options', 'arctecture'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-admin-generic',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => false,
    // Show the time the page took to load, etc
    'update_notice'        => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority'        => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => class_exists('CmssuperheroesCore') ? $theme->get('TextDomain') : '',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => '',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'theme-options',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    ),
    'templates_path'       => class_exists('CmssuperheroesCore') ? cmssuperheroes()->path('APP_DIR') . '/templates/redux/' : '',
);

Redux::SetArgs($opt_name, $args);

/*--------------------------------------------------------------
# General
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('General', 'arctecture'),
    'icon'   => 'el-icon-home',
    'fields' => array(
        array(
            'id'       => 'show_page_loading',
            'type'     => 'switch',
            'title'    => esc_html__('Enable Page Loading', 'arctecture'),
            'subtitle' => esc_html__('Enable Page Loading Effect When You Load Site', 'arctecture'),
            'default'  => false
        ),
    )
));

/*--------------------------------------------------------------
# Header
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Header', 'arctecture'),
    'icon'   => 'el-icon-website',
    'fields' => array(
        array(
            'id'       => 'header_layout',
            'type'     => 'image_select',
            'title'    => esc_html__('Layout', 'arctecture'),
            'subtitle' => esc_html__('Select a layout for header.', 'arctecture'),
            'options'  => array(
                '1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
                '2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
            ),
            'default'  => '1'
        ),
        array(
            'id'       => 'h_seach_icon',
            'type'     => 'switch',
            'title'    => esc_html__('Search Icon', 'arctecture'),
            'default'  => true
        ),
        array(
            'id'       => 'sticky_on',
            'type'     => 'switch',
            'title'    => esc_html__('Sticky Header', 'arctecture'),
            'subtitle' => esc_html__('Header will be sticked when applicable.', 'arctecture'),
            'default'  => true
        ),
        array(
            'id'       => 'bg_topbar',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Topbar', 'arctecture'),
            'subtitle' => esc_html__('Select background-color for Topbar.', 'arctecture'),
            'output' => array('background-color' => '.topbar-panel')
        ),
        array(
            'id'       => 'bg_topbar_padding',
            'type'     => 'spacing',
            'title'    => esc_html__('Paddings', 'arctecture'),
            'subtitle' => esc_html__('Paddings Top & Bottom for TopBar.', 'arctecture'),
            'mode'     => 'padding',
            'units'    => array('px'),
            'right'    => false,
            'left'     => false,
            'default'  => array(
                'padding-top'    => '',
                'padding-bottom' => ''
            ),
            'output'   => array('.topbar-panel')
        ),
        array(
            'id'       => 'bg_logo_menu',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Logo & Menu', 'arctecture'),
            'subtitle' => esc_html__('Select background-color for Logo & Menu Section.', 'arctecture'),
            'output' => array('background-color' => 'body #site-header-wrap #headroom.site-header-main')
        ),
        array(
            'id'       => 'bg_logo_menu_padding',
            'type'     => 'spacing',
            'title'    => esc_html__('Paddings', 'arctecture'),
            'subtitle' => esc_html__('Paddings Top & Bottom for Logo & Menu Section.', 'arctecture'),
            'mode'     => 'padding',
            'units'    => array('px'),
            'right'    => false,
            'left'     => false,
            'default'  => array(
                'padding-top'    => '',
                'padding-bottom' => ''
            ),
            'output'   => array('.site-header-main')
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Top Bar', 'arctecture'),
    'icon'       => 'el-icon-circle-arrow-right',
    'subsection' => true,
    'fields'     => array(
        array(
            'id' => 'top_bar_email',
            'type' => 'text',
            'title' => esc_html__('Email', 'arctecture'),
            'default' => 'arcarchitecture@mail.com',
        ),
        array(
            'id' => 'top_bar_address',
            'type' => 'text',
            'title' => esc_html__('Address', 'arctecture'),
            'default' => '137 Worcester St, Barrow-in-Furness LA13 9DB, UK',
        ),
        array(
            'id'      => 'top_bar_social',
            'type'    => 'sorter',
            'title'   => 'Social',
            'desc'    => 'Choose which social networks are displayed and edit where they link to.',
            'options' => array(
                'enabled'  => array(
                    'facebook'  => 'Facebook', 
                    'twitter'   => 'Twitter', 
                    'google'    => 'Google',
                    'skype'     => 'Skype',
                    'instagram' => 'Instagram',
                ),
                'disabled' => array(
                    'tripadvisor'     => 'Tripadvisor',
                    'youtube'   => 'Youtube', 
                    'vimeo'     => 'Vimeo', 
                    'tumblr'    => 'Tumblr',
                    'pinterest' => 'Pinterest',
                    'yelp'      => 'Yelp',
                    'linkedin'  => 'Linkedin',
                )
            ),
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Logo', 'arctecture'),
    'icon'       => 'el el-picture',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'logo_light',
            'type'     => 'media',
            'title'    => esc_html__('Logo', 'arctecture'),
             'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/logo-light.png'
            )
        ),
        array(
            'id'       => 'logo_mobile',
            'type'     => 'media',
            'title'    => esc_html__('Logo Mobile & Tablet', 'arctecture'),
             'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/logo-dark.png'
            )
        ),
        array(
            'id'       => 'logo_maxh',
            'type'     => 'dimensions',
            'title'    => esc_html__('Logo Max height', 'arctecture'),
            'subtitle' => esc_html__('Set maximum height for your logo, just in case the logo is too large.', 'arctecture'),
            'width'    => false,
            'unit'     => 'px'
        ),
        array(
            'id'       => 'logo_mobile_maxh',
            'type'     => 'dimensions',
            'title'    => esc_html__('Logo Mobile Max height', 'arctecture'),
            'subtitle' => esc_html__('Set maximum height for your logo on mobile, just in case the logo is too large.', 'arctecture'),
            'width'    => false,
            'unit'     => 'px'
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Navigation', 'arctecture'),
    'icon'       => 'el el-lines',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'font_menu',
            'type'        => 'typography',
            'title'       => esc_html__('Menu Font', 'arctecture'),
            'subtitle'    => esc_html__('Menu typography.', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'font-style'  => false,
            'font-weight'  => true,
            'text-align'  => false,
            'font-size'  => true,
            'line-height'  => false,
            'font-color'  => true,
            'output'      => array('.main-navigation li a, #site-header-wrap .site-menu-right .menu-right-item'),
            'units'       => 'px'
        )
    )
));

/*--------------------------------------------------------------
# Page Title area
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Page Title', 'arctecture'),
    'icon'   => 'el-icon-map-marker',
    'fields' => array(
        array(
            'id'       => 'ptitle_layout',
            'type'     => 'image_select',
            'title'    => esc_html__('Layout', 'arctecture'),
            'subtitle' => esc_html__('Select a layout for page title.', 'arctecture'),
            'options'  => array(
                '1' => get_template_directory_uri() . '/assets/images/page-title-layout/p1.jpg',
            ),
        ),
        // array(
        //     'id'       => 'ptitle_color',
        //     'type'     => 'color',
        //     'title'    => esc_html__('Title Color', 'arctecture'),
        //     'subtitle' => esc_html__('Page title color.', 'arctecture'),
        //     'output'   => array('#pagetitle h1.page-title'),
        //     'default'  => '',
        // ),
        array(
            'id'       => 'ptitle_bg_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Overlay', 'arctecture'),
            'subtitle' => esc_html__('Page title background color overlay', 'arctecture'),
            'output' => array('background-color' => '#pagetitle'),
        ),
        array(
            'id'       => 'ptitle_bg',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'arctecture'),
            'subtitle' => esc_html__('Page title background.', 'arctecture'),
            'output'   => array('#pagetitle'),
            'background-color'   => false,
        ),
        array(
            'id'       => 'ptitle_paddings',
            'type'     => 'spacing',
            'title'    => esc_html__('Paddings', 'arctecture'),
            'subtitle' => esc_html__('Page title paddings.', 'arctecture'),
            'mode'     => 'padding',
            'units'    => array('em', 'px', '%'),
            'top'      => true,
            'right'    => false,
            'bottom'   => true,
            'left'     => false,
            'output'   => array('#pagetitle'),
            'default'  => array(
                'top'    => '',
                'right'  => '',
                'bottom' => '',
                'left'   => '',
                'units'  => 'px',
            ),
        ),
        array(
            'id'          => 'font_page_title',
            'type'        => 'typography',
            'title'       => esc_html__('Page Title Font', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'font-style'  => false,
            'font-weight'  => false,
            'text-align'  => false,
            'font-size'  => false,
            'line-height'  => false,
            'font-color'  => false,
            'output'      => array('#pagetitle h1.page-title'),
            'units'       => 'px',
        ),
        array(
            'id'      => 'breadcrumb_on',
            'type'    => 'switch',
            'title'   => esc_html__('Breadcrumb', 'arctecture'),
            'default' => true,
        ),
    )
));

/*--------------------------------------------------------------
# WordPress default content
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title' => esc_html__('Content', 'arctecture'),
    'icon'  => 'el-icon-pencil',
    'fields'     => array(
        array(
            'id'       => 'content_bg_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Color', 'arctecture'),
            'subtitle' => esc_html__('Content background color.', 'arctecture'),
            'output' => array('background-color' => '#content')
        ),
        array(
            'id'             => 'content_padding',
            'type'           => 'spacing',
            'output'         => array('#content'),
            'right'   => false,
            'left'    => false,
            'mode'           => 'padding',
            'units'          => array('px'),
            'units_extended' => 'false',
            'title'          => esc_html__('Content Padding', 'arctecture'),
            'desc'           => esc_html__('Default: Top-90px, Bottom-90px', 'arctecture'),
            'default'            => array(
                'padding-top'   => '',  
                'padding-bottom'   => '',  
                'units'          => 'px', 
            )
        ),
    )
));


Redux::setSection($opt_name, array(
    'title'      => esc_html__('Archive', 'arctecture'),
    'icon'       => 'el-icon-list',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'archive_sidebar_pos',
            'type'     => 'button_set',
            'title'    => esc_html__('Sidebar Position', 'arctecture'),
            'subtitle' => esc_html__('Select a sidebar position for blog home, archive, search...', 'arctecture'),
            'options'  => array(
                'left'  => esc_html__('Left', 'arctecture'),
                'right' => esc_html__('Right', 'arctecture'),
                'none'  => esc_html__('Disabled', 'arctecture')
            ),
            'default'  => 'right'
        ),
        array(
            'id'       => 'archive_author_on',
            'title'    => esc_html__('Author', 'arctecture'),
            'subtitle' => esc_html__('Show author name on each post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => false,
        ),
        array(
            'id'       => 'archive_date_on',
            'title'    => esc_html__('Date', 'arctecture'),
            'subtitle' => esc_html__('Show date posted on each post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_categories_on',
            'title'    => esc_html__('Categories', 'arctecture'),
            'subtitle' => esc_html__('Show category names on each post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => false,
        ),
        array(
            'id'       => 'archive_comments_on',
            'title'    => esc_html__('Comments', 'arctecture'),
            'subtitle' => esc_html__('Show comments count on each post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => false,
        )
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Single Blog', 'arctecture'),
    'icon'       => 'el-icon-file-edit',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'post_author_on',
            'title'    => esc_html__('Author', 'arctecture'),
            'subtitle' => esc_html__('Show author name on single post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_date_on',
            'title'    => esc_html__('Date', 'arctecture'),
            'subtitle' => esc_html__('Show date on single post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_categories_on',
            'title'    => esc_html__('Categories', 'arctecture'),
            'subtitle' => esc_html__('Show category names on single post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => false
        ),
        array(
            'id'       => 'post_tags_on',
            'title'    => esc_html__('Tags', 'arctecture'),
            'subtitle' => esc_html__('Show tag names on single post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => false
        ),
        array(
            'id'       => 'post_comments_on',
            'title'    => esc_html__('Comments', 'arctecture'),
            'subtitle' => esc_html__('Show comments count on single post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_author_info_on',
            'title'    => esc_html__('Author Info', 'arctecture'),
            'subtitle' => esc_html__('Show author info on single post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => false
        ),
        array(
            'id'       => 'post_navigation_link_on',
            'title'    => esc_html__('Navigation Links', 'arctecture'),
            'subtitle' => esc_html__('Show navigation link info on single post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => false
        ),
        array(
            'id'       => 'post_comments_form_on',
            'title'    => esc_html__('Comments Form', 'arctecture'),
            'subtitle' => esc_html__('Show comments form on single post.', 'arctecture'),
            'type'     => 'switch',
            'default'  => true
        )
    )
));


/*--------------------------------------------------------------
# Shop
--------------------------------------------------------------*/
if(class_exists('Woocommerce')) {
    Redux::setSection($opt_name, array(
        'title'  => esc_html__('Shop', 'arctecture'),
        'icon'   => 'el el-shopping-cart',
        'fields' => array(
            array(
                'id'       => 'sidebar_shop',
                'type'     => 'button_set',
                'title'    => esc_html__('Sidebar Position', 'arctecture'),
                'subtitle' => esc_html__('Select a sidebar position for shop', 'arctecture'),
                'options'  => array(
                    'left'  => esc_html__('Left', 'arctecture'),
                    'right' => esc_html__('Right', 'arctecture'),
                    'none'  => esc_html__('Disabled', 'arctecture')
                ),
                'default'  => 'right'
            ),
            array(
                'title' => esc_html__('Products displayed per page', 'arctecture'),
                'id' => 'product_per_page',
                'type' => 'slider',
                'subtitle' => esc_html__('Number product to show', 'arctecture'),
                'default' => 6,
                'min'  => 6,
                'step' => 1,
                'max' => 50,
                'display_value' => 'text'
            ),
            array(
                'title' => esc_html__('Page Title', 'arctecture'),
                'type'  => 'section',
                'id' => 'shop_page_title',
                'indent' => true
            ),
            array(
                'id'       => 'shop_page_title_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background', 'arctecture'),
                'subtitle' => esc_html__('Page title background.', 'arctecture'),
                'output'   => array('.woocommerce #pagetitle, .woocommerce-page #pagetitle'),
                'background-color'   => false,
            ),
        )
    ));
}

/*--------------------------------------------------------------
# Page 404
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Page 404', 'arctecture'),
    'icon'   => 'el-icon-map-marker',
    'fields' => array(
        array(
            'id'       => 'img_404',
            'type'     => 'media',
            'title'    => esc_html__('Image 404', 'arctecture'),
            'subtitle' => esc_html__('Select image for page 404', 'arctecture'),
            'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/imgtext-404.png'
            )
        ),
        array(
            'id' => 'sub_title_404',
            'type' => 'text',
            'title' => esc_html__('Subtitle 404', 'arctecture'),
            'default' => 'oops! look like you are lost',
        ),
        array(
            'id' => 'back_to_home',
            'type' => 'text',
            'title' => esc_html__('Button Home', 'arctecture'),
            'default' => 'Back To Home',
        ),
    )
));

/*--------------------------------------------------------------
# Colors
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Colors', 'arctecture'),
    'icon'   => 'el-icon-file-edit',
    'fields' => array(
        array(
            'id'          => 'primary_color',
            'type'        => 'color',
            'title'       => esc_html__('Primary Color', 'arctecture'),
            'transparent' => false,
            'default'     => '#fab702'
        ),
        // array(
        //     'id'      => 'link_color',
        //     'type'    => 'link_color',
        //     'title'   => __('Link Colors', 'arctecture'),
        //     'default' => array(
        //         'regular' => '#ffb400',
        //         'hover'   => false,
        //         'active'  => false,
        //     ),
        //     'output'  => array('a')
        // )
    )
));

/*--------------------------------------------------------------
# Typography
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Typography', 'arctecture'),
    'icon'   => 'el-icon-text-width',
    'fields' => array(
        array(
            'id'          => 'font_main',
            'type'        => 'typography',
            'title'       => esc_html__('Main Font', 'arctecture'),
            'subtitle'    => esc_html__('Typography option with each property can be called individually.', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'output'      => array('body'),
            'units'       => 'px'
        ),
        array(
            'id'          => 'font_h1',
            'type'        => 'typography',
            'title'       => esc_html__('H1', 'arctecture'),
            'subtitle'    => esc_html__('Heading 1 typography.', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'output'      => array('h1', '.h1'),
            'units'       => 'px'
        ),
        array(
            'id'          => 'font_h2',
            'type'        => 'typography',
            'title'       => esc_html__('H2', 'arctecture'),
            'subtitle'    => esc_html__('Heading 2 typography.', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'output'      => array('h2', '.h2'),
            'units'       => 'px'
        ),
        array(
            'id'          => 'font_h3',
            'type'        => 'typography',
            'title'       => esc_html__('H3', 'arctecture'),
            'subtitle'    => esc_html__('Heading 3 typography.', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'output'      => array('h3', '.h3'),
            'units'       => 'px'
        ),
        array(
            'id'          => 'font_h4',
            'type'        => 'typography',
            'title'       => esc_html__('H4', 'arctecture'),
            'subtitle'    => esc_html__('Heading 4 typography.', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'output'      => array('h4', '.h4'),
            'units'       => 'px'
        ),
        array(
            'id'          => 'font_h5',
            'type'        => 'typography',
            'title'       => esc_html__('H5', 'arctecture'),
            'subtitle'    => esc_html__('Heading 5 typography.', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'output'      => array('h5', '.h5'),
            'units'       => 'px'
        ),
        array(
            'id'          => 'font_h6',
            'type'        => 'typography',
            'title'       => esc_html__('H6', 'arctecture'),
            'subtitle'    => esc_html__('Heading 6 typography.', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'output'      => array('h6', '.h6'),
            'units'       => 'px'
        )
    )
));

$custom_font_selectors_1 = Redux::getOption($opt_name, 'custom_font_selectors_1');
$custom_font_selectors_1 = !empty($custom_font_selectors_1) ? explode(',', $custom_font_selectors_1) : array();

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Extra Fonts', 'arctecture'),
    'icon'       => 'el el-fontsize',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'custom_font_1',
            'type'        => 'typography',
            'title'       => esc_html__('Custom Font', 'arctecture'),
            'subtitle'    => esc_html__('Typography option with each property can be called individually.', 'arctecture'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'output'      => $custom_font_selectors_1,
            'units'       => 'px',

        ),
        array(
            'id'       => 'custom_font_selectors_1',
            'type'     => 'textarea',
            'title'    => esc_html__('CSS Selectors', 'arctecture'),
            'subtitle' => esc_html__('Add css selectors to apply above font.', 'arctecture'),
            'validate' => 'no_html'
        )
    )
));


/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Footer', 'arctecture'),
    'icon'   => 'el el-website',
    'fields' => array(
        array(
            'id'       => 'footer_layout',
            'type'     => 'image_select',
            'title'    => esc_html__('Layout', 'arctecture'),
            'subtitle' => esc_html__('Select a layout for upper footer area.', 'arctecture'),
            'options'  => array(
                '1' => get_template_directory_uri() . '/assets/images/footer-layout/f1.jpg',
                '2' => get_template_directory_uri() . '/assets/images/footer-layout/f2.jpg',
            ),
            'default'  => '1'
        ),
        array(
            'id'       => 'footer_bg',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'arctecture'),
            'subtitle' => esc_html__('Footer background.', 'arctecture'),
            'output'   => array('.site-footer'),
            'background-color'   => false,
        ),
        array(
            'id'       => 'footer_bg_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Overlay', 'arctecture'),
            'subtitle' => esc_html__('Footer top background color overlay', 'arctecture'),
            'output' => array('background-color' => 'body .site-footer::before')
        ),
        array(
            'id'       => 'back_totop_on',
            'type'     => 'switch',
            'title'    => esc_html__('Back to Top Button', 'arctecture'),
            'subtitle' => esc_html__('Show back to top button when scrolled down.', 'arctecture'),
            'default'  => true
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Footer Top', 'arctecture'),
    'icon'       => 'el el-circle-arrow-right',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'footer_top_column',
            'type'     => 'button_set',
            'title'    => esc_html__('Columns', 'arctecture'),
            'options'  => array(
                '2'  => esc_html__('2 Column', 'arctecture'),
                '3'  => esc_html__('3 Column', 'arctecture'),
                '4'  => esc_html__('4 Column', 'arctecture'),
            ),
            'default'  => '3',
        ),
        array(
            'id'       => 'footer_top_paddings',
            'type'     => 'spacing',
            'title'    => esc_html__('Paddings', 'arctecture'),
            'subtitle' => esc_html__('Footer top paddings.', 'arctecture'),
            'mode'     => 'padding',
            'units'    => array('px'),
            'right'    => false,
            'left'     => false,
            'default'  => array(
                'padding-top'    => '',
                'padding-bottom' => ''
            ),
            'output'   => array('.top-footer')
        ),
        array(
            'id'    => 'footer_top_heading_color',
            'type'  => 'color',
            'title' => esc_html__('Widget Title Color', 'arctecture'),
            'output'   => array('.top-footer .widget-title')
        ),
        array(
            'id'    => 'footer_top_color1',
            'type'  => 'color',
            'title' => esc_html__('Text Color1', 'arctecture'),
            'output'   => array('.top-footer .cms-widget-footer ul li:nth-child(1), .top-footer .cms-widget-footer ul li:nth-child(3)'),
        ),
        array(
            'id'    => 'footer_top_colo2',
            'type'  => 'color',
            'title' => esc_html__('Text Color2', 'arctecture'),
            'output'   => array('.top-footer'),
        ),
        // array(
        //     'id'      => 'footer_top_link_color',
        //     'type'    => 'link_color',
        //     'title'   => esc_html__('Links Color', 'arctecture'),
        //     'regular' => true,
        //     'hover'   => true,
        //     'active'  => true,
        //     'visited' => true,
        //     'output'  => array('.top-footer a'),
        // ),
    )
));


Redux::setSection($opt_name, array(
    'title'      => esc_html__('Footer Copyright', 'arctecture'),
    'icon'       => 'el el-circle-arrow-right',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'footer_copyright_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Color', 'arctecture'),
            'subtitle' => esc_html__('Footer Copyright background color', 'arctecture'),
            'output' => array('background-color' => 'body .site-footer .bottom-footer')
        ),        
        array(
            'id'=>'footer_copyright',
            'type' => 'textarea',
            'title' => esc_html__('Copyright', 'arctecture'),
            'validate' => 'html_custom',
            'default' => '© Copyright 2018 - <a href="http://farost.net"> Farost</a> - All right reserved.',
            'subtitle' => esc_html__('Custom HTML Allowed: a, br, em, strong, span, p, div, h1->h6', 'arctecture'),
            'allowed_html' => array(
                'a' => array(
                    'href' => array(),
                    'title' => array(),
                    'class' => array(),
                ),
                'br' => array(),
                'em' => array(),
                'strong' => array(),
                'span' => array(),
                'p' => array(),
                'div' => array(
                    'class' => array()
                ),
                'h1' => array(
                    'class' => array()
                ),
                'h2' => array(
                    'class' => array()
                ),
                'h3' => array(
                    'class' => array()
                ),
                'h4' => array(
                    'class' => array()
                ),
                'h5' => array(
                    'class' => array()
                ),
                'h6' => array(
                    'class' => array()
                ),
                'ul' => array(
                    'class' => array()
                ),
                'li' => array(),
            )
        ),

        array(
            'id'       => 'footer_bottom_paddings',
            'type'     => 'spacing',
            'title'    => esc_html__('Paddings', 'arctecture'),
            'subtitle' => esc_html__('Footer bottom paddings.', 'arctecture'),
            'mode'     => 'padding',
            'units'    => array('px'),
            'right'    => false,
            'left'     => false,
            'default'  => array(
                'padding-top'    => '',
                'padding-bottom' => ''
            ),
            'output'   => array('.bottom-footer')
        ),
        array(
            'id'    => 'footer_bottom_color',
            'type'  => 'color',
            'title' => esc_html__('Text Color', 'arctecture'),
            'output'  => array('body .bottom-footer .copyright-content'),
        ),
        array(
            'id'      => 'footer_bottom_link_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Links Color', 'arctecture'),
            'regular' => true,
            'hover'   => true,
            'active'  => false,
            'visited' => false,
            'output'  => array('body .bottom-footer .copyright-content a'),
        ),
    )
));

/* Social Media */
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Social Media', 'arctecture'),
    'icon'       => 'el el-twitter',
    'subsection' => false,
    'fields'     => array(
        array(
            'id'      => 'social_facebook_url',
            'type'    => 'text',
            'title'   => esc_html__('Facebook URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_twitter_url',
            'type'    => 'text',
            'title'   => esc_html__('Twitter URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_inkedin_url',
            'type'    => 'text',
            'title'   => esc_html__('Inkedin URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_rss_url',
            'type'    => 'text',
            'title'   => esc_html__('Rss URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_instagram_url',
            'type'    => 'text',
            'title'   => esc_html__('Instagram URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_google_url',
            'type'    => 'text',
            'title'   => esc_html__('Google URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_skype_url',
            'type'    => 'text',
            'title'   => esc_html__('Skype URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_pinterest_url',
            'type'    => 'text',
            'title'   => esc_html__('Pinterest URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_vimeo_url',
            'type'    => 'text',
            'title'   => esc_html__('Vimeo URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_youtube_url',
            'type'    => 'text',
            'title'   => esc_html__('Youtube URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_yelp_url',
            'type'    => 'text',
            'title'   => esc_html__('Yelp URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_tumblr_url',
            'type'    => 'text',
            'title'   => esc_html__('Tumblr URL', 'arctecture'),
            'default' => '#',
        ),
        array(
            'id'      => 'social_tripadvisor_url',
            'type'    => 'text',
            'title'   => esc_html__('Tripadvisor URL', 'arctecture'),
            'default' => '#',
        ),
    )
));

/* Custom Code /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Custom Code', 'arctecture'),
    'icon'   => 'el-icon-edit',
    'fields' => array(

        array(
            'id'       => 'site_header_code',
            'type'     => 'textarea',
            'theme'    => 'chrome',
            'title'    => esc_html__('Header Custom Codes', 'arctecture'),
            'subtitle' => esc_html__('It will insert the code to wp_head hook.', 'arctecture'),
        ),
        array(
            'id'       => 'site_footer_code',
            'type'     => 'textarea',
            'theme'    => 'chrome',
            'title'    => esc_html__('Footer Custom Codes', 'arctecture'),
            'subtitle' => esc_html__('It will insert the code to wp_footer hook.', 'arctecture'),
        ),

    ),
));

/* Custom CSS /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Custom CSS', 'arctecture'),
    'icon'   => 'el-icon-adjust-alt',
    'fields' => array(

        array(
            'id'   => 'customcss',
            'type' => 'info',
            'desc' => esc_html__('Custom CSS', 'arctecture')
        ),

        array(
            'id'       => 'site_css',
            'type'     => 'ace_editor',
            'title'    => esc_html__('CSS Code', 'arctecture'),
            'subtitle' => esc_html__('Advanced CSS Options. You can paste your custom CSS Code here.', 'arctecture'),
            'mode'     => 'css',
            'validate' => 'css',
            'theme'    => 'chrome',
            'default'  => ""
        ),

    ),
));