<?php
/**
 * Template part for displaying posts in loop
 *
 * @package Arctecture
 */
?>

<article id="post-<?php the_ID(); ?>" <?php post_class('single-hentry'); ?>>
    <div class="entry-featured">
        <?php if (has_post_format('gallery')) : ?>
            <?php
            $light_box = arctecture_get_post_format_value('post-gallery-lightbox', '0'); //Value is string ("0" or "1")
            $gallery_list = explode(',', arctecture_get_post_format_value('post-gallery-images', '')); //Value is array of id image list
            wp_enqueue_script('owl-carousel');
            wp_enqueue_script('arctecture-carousel');
            ?>
            <div class="cms-carousel owl-carousel featured-active <?php if ($light_box) {
                echo 'images-light-box';
            } ?>" data-item-xs="1" data-item-sm="1" data-item-md="1" data-item-lg="1" data-margin="30" data-loop="true"
                 data-autoplay="true" data-autoplaytimeout="5000" data-smartspeed="250" data-center="false"
                 data-arrows="true" data-bullets="false" data-stagepadding="0" data-stagepaddingsm="0" data-rtl="false">
                <?php
                foreach ($gallery_list as $img_id):
                    ?>
                    <div class="cms-carousel-item">
                        <a class="light-box" href="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'full')); ?>">
                            <img src="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'large')); ?>"
                                    alt="<?php echo esc_attr(get_post_meta($img_id, '_wp_attachment_image_alt', true)) ?>">
                        </a>
                    </div>
                <?php
                endforeach;
                ?>
            </div>
        <?php elseif (has_post_format('quote')) : ?>
            <?php
            $quote_text = arctecture_get_post_format_value('post-quote-cite', ''); //Value is string
            echo esc_attr($quote_text);
            ?>
        <?php elseif (has_post_format('link')) : ?>
            <?php
            $link_pf = arctecture_get_post_format_value('post-link-url', '#');// Value is url
            echo esc_url($link_pf);
            ?>
        <?php elseif (has_post_format('video')) : ?>
            <div class="entry-video featured-active">
                <?php
                $video_url = arctecture_get_post_format_value('post-video-url', '#');
                $video_file = arctecture_get_post_format_value('post-video-file', '');
                $video_html = arctecture_get_post_format_value('post-video-html', '');
                $video = '';
                if (!empty($video_url)) {
                    global $wp_embed;
                    echo do_shortcode($wp_embed->run_shortcode('[embed]' . esc_url($video_url) . '[/embed]'));
                } elseif (!empty($video_file)) {
                    if (strpos('[embed', $video_file)) {
                        global $wp_embed;
                        echo do_shortcode($wp_embed->run_shortcode($video_file));
                    } else {
                        echo do_shortcode($video_file);
                    }
                } else {
                    if ('' != $video_html) {
                        echo wp_kses_post($video_html);
                    }
                }
                ?>
            </div>
        <?php elseif (has_post_format('audio')) : ?>
            <?php
            $audio_url = arctecture_get_post_format_value('post-audio-url', '#');
            echo esc_url($audio_url);
            ?>
        <?php else : ?>

            <?php
            if (has_post_thumbnail()) {
                echo '<div class="post-image">'; ?>
                <a href="<?php echo esc_url(get_permalink()); ?>"><?php the_post_thumbnail('large'); ?></a>
                <?php echo '</div>';
            }
            ?>
        <?php endif; ?>
    </div><!-- .entry-featured -->
    <div class="entry-holder">
        <h2 class="entry-title">
            <a href="<?php echo esc_url(get_permalink()); ?>" rel="bookmark">
                <?php the_title(); ?>
            </a>
        </h2>
        <?php arctecture_archive_meta(); ?>
        <div class="entry-content clearfix">
            <?php
                arctecture_entry_excerpt();
                wp_link_pages(array(
                    'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__('Pages:', 'arctecture') . '</span>',
                    'after'       => '</div>',
                    'link_before' => '<span>',
                    'link_after'  => '</span>',
                ));
            ?>
        </div>
        <div class="gallery-bottom">
            <?php
            $gallery_list1 = arctecture_get_page_opt('post-gallery-images2');
            $gallery_list2 = explode(',', $gallery_list1);
            if (!empty($gallery_list2)) : ?>
                <ul class="images-light-box">
                    <?php foreach ($gallery_list2 as $img_id): ?>
                        <li>
                            <a class="light-box"
                               href="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'full')); ?>">
                                <img src="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'large')); ?>"
                                     alt="<?php echo esc_attr(get_post_meta($img_id, '_wp_attachment_image_alt', true)) ?>">
                            </a>
                        </li>
                    <?php endforeach; ?>
                </ul>
            <?php endif; ?>
        </div>

        <div class="entry-more">
            <a href="<?php echo esc_url(get_permalink()); ?>"><?php echo esc_html__('Read More', 'arctecture') ?> <i
                        class="fa fa-angle-double-right"></i></a>
            <?php arctecture_socials_share(); ?>
        </div>
    </div>
</article><!-- #post -->