<?php
/**
 * @Template: cms_carousel.php
 * @since: 1.0.0
 * @author: KP
 * @descriptions:
 * @create: 01-Feb-18
 */

if (!defined('ABSPATH')) exit;

if (!class_exists('CMS_Carousel')) {
    class CMS_Carousel
    {
        public function __construct()
        {
            add_action('init', array($this, 'add_shortcode'));
            add_action('vc_before_init', array($this, 'add_param'));
        }

        function add_shortcode()
        {
            $enable_cms_carousel = apply_filters('enable_cms_carousel', false);
            if ($enable_cms_carousel) {
                add_shortcode('cms_carousel', array($this, 'add_shortcode_cms_carousel'));
            }
        }

        function add_shortcode_cms_carousel($atts, $contents = '')
        {
            wp_enqueue_script( 'owl-carousel' );
            wp_enqueue_script( 'arctecture-carousel' );
            $atts = shortcode_atts(array(
                'col_xs'           => '1',
                'col_sm'           => '2',
                'col_md'           => '3',
                'col_lg'           => '4',
                'margin'           => '30',
                'loop'             => 'false',
                'autoplay'         => 'false',
                'autoplay_timeout' => '5000',
                'smart_speed'      => '250',
                'center'           => 'false',
                'stage_padding'    => '0',
                'arrows'           => 'false',
                'bullets'          => 'false',
                'el_class'          => '',
            ), $atts);
            $contents = $this->cms_columnize_content($contents);
            if($contents[count($contents)-1] === ""){
                array_pop($contents);
            }
            return cms_get_template_file__('cms_carousel.php', array('atts' => $atts, 'contents' => $contents));
        }

        function add_param()
        {
            $enable_cms_carousel = apply_filters('enable_cms_carousel', false);
            if ($enable_cms_carousel) {
                $args = array(
                    "name"                    => esc_html__("Carousel", 'arctecture'),
                    "base"                    => "cms_carousel",
                    "class"                   => "cms_carousel",
                    "content_element"         => true,
                    "show_settings_on_create" => false,
                    "is_container"            => true,
                    "controls"                => "full",
                    "category"                => esc_html__('Theme Shortcodes', 'arctecture'),
                    "as_parent"               => array(
                        'except' => 'cms_carousel'
                    ),
                    "params"                  => array(
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__( 'Extra class name', 'arctecture' ),
                            'param_name' => 'el_class',
                            'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in Custom CSS.', 'arctecture' ),
                        ),
                    ),
                    "js_view"                 => 'VcColumnView'
                );
                $args = arctecture_add_vc_extra_param($args);
                vc_map($args);
            }
        }

        protected function cms_columnize_content(&$content)
        {
            global $shortcode_tags;
            preg_match_all('@\[([^<>&/\[\]\x00-\x20=]++)@', $content, $matches);
            $tagnames = array_intersect(array_keys($shortcode_tags), $matches[1]);
            $pattern = get_shortcode_regex();
            foreach ($tagnames as $tag) {
                $start = "[$tag";
                $end = "[/$tag]";

                if (strpos($content, $end) !== false) {
                    $content = str_replace($start, '' . $start, $content);
                    $content = str_replace($end, $end . '||', $content);
                }
                $content = str_replace('][', ']||[', $content);

            }
            return explode('||', $content);

        }
    }

    new CMS_Carousel();

    if (class_exists('WPBakeryShortCodesContainer') && !class_exists('CMS_ShortcodeContainer')) {

        /**
         * Shortcode COntainer class
         */
        class CMS_ShortcodeContainer extends WPBakeryShortCodesContainer
        {

            /**
             * [$controls_css_settings description]
             * @var string
             */
            protected $controls_css_settings = 'out-tc vc_controls-content-widget';

            /**
             * [$controls_list description]
             * @var array
             */
            protected $controls_list = array('add', 'edit', 'delete');

            /**
             * @param $width
             * @param $i
             *
             * @return string
             */
            public function mainHtmlBlockParams($width, $i)
            {
                $sortable = (vc_user_access_check_shortcode_all('cms_carousel') ? 'wpb_sortable' : 'vc-non-draggable');

                return 'data-element_type="' . 'cms_carousel' . '" class="cms-content-holder wpb_' . 'cms_carousel' . ' ' . $sortable . ' wpb_content_holder vc_shortcodes_container"' . $this->customAdminBlockParams();
            }

            public function getColumnControls($controls = 'full', $extended_css = '')
            {

                $column_controls = $this->getColumnControlsModular();

                $column_controls = str_replace('vc_element-move"', 'vc_element-move" data-vc-control="move"', $column_controls);
                $column_controls = str_replace('vc_edit"', 'vc_edit" data-vc-control="add"', $column_controls);
                $column_controls = str_replace('vc_control-btn-edit"', 'vc_control-btn-edit" data-vc-control="edit"', $column_controls);
                $column_controls = str_replace('vc_control-btn-delete"', 'vc_control-btn-delete" data-vc-control="delete"', $column_controls);

                return $column_controls;
            }

            public function contentAdmin($atts, $content = null)
            {

                $width = $el_class = '';

                $atts = shortcode_atts($this->predefined_atts, $atts);
                extract($atts);
                $this->atts = $atts;
                $output = '';

                for ($i = 0; $i < count($width); $i++) {

                    $output .= '<div ' . $this->mainHtmlBlockParams($width, $i) . '>';

                    if ($this->backened_editor_prepend_controls) {
                        $output .= $this->getColumnControls('full', 'vc_controls-out-tc vc_controls-content-widget');
                    }


                    $output .= '<div class="cms-param-holder">';

                    $output .= $this->paramsHtmlHolders($atts);

                    $output .= '</div>';

                    $output .= '<div class="wpb_element_wrapper">';

                    $output .= '<div ' . $this->containerHtmlBlockParams($width, $i) . '>';

                    $output .= do_shortcode(shortcode_unautop($content));

                    $output .= '</div>';

                    $output .= '</div>';

                    $output .= '</div>';
                }

                return $output;
            }
        }
    }

    if (class_exists('WPBakeryShortCodesContainer')) {

        class WPBakeryShortCode_cms_carousel extends CMS_ShortcodeContainer
        {
        }

    }
}