<?php defined( 'ABSPATH' ) or exit( -1 );
/**
 * Recent Posts widgets
 *
 * @package Arctecture
 * @version 1.0
 */

class CMS_Recent_Project_Widget extends WP_Widget
{
    function __construct()
    {
        parent::__construct(
            'cms_recent_portfolio',
            esc_html__( 'CMS Recent Project', 'arctecture' ),
            array(
                'description' => __( 'Shows your most recent Project.', 'arctecture' ),
                'customize_selective_refresh' => true,
            )
        );
    }

    /**
     * Outputs the HTML for this widget.
     *
     * @param array $args An array of standard parameters for widgets in this theme
     * @param array $instance An array of settings for this widget instance
     * @return void Echoes it's output
     **/
    function widget( $args, $instance )
    {
        $instance = wp_parse_args( (array) $instance, array(
            'title'         => esc_html__( 'Recent Project', 'arctecture' ),
            'number'        => 4,
            'show_category'     => true,
            'show_date'     => true,
            'show_comments' => true
        ) );

        $title = empty( $instance['title'] ) ? esc_html__( 'Recent Project', 'arctecture' ) : $instance['title'];
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

        echo wp_kses_post($args['before_widget']);

        echo wp_kses_post($args['before_title']) . wp_kses_post($title) . wp_kses_post($args['after_title']);

        $number = absint( $instance['number'] );
        if ( $number <= 0 || $number > 10)
        {
            $number = 4;
        }

        $show_category     = (bool)$instance['show_category'];
        $show_date     = (bool)$instance['show_date'];
        $show_comments = (bool)$instance['show_comments'];

        $r = new WP_Query( array(
            'post_type'           => 'portfolio',
            'posts_per_page'      => $number,
            'no_found_rows'       => true,
            'post_status'         => 'publish',
            'ignore_sticky_posts' => true
        ) );

        if ( $r->have_posts() )
        {
            echo '<ul class="list-item-port">';
            while ( $r->have_posts() )
            {
                $r->the_post();
                global $post;
                 
                    if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false)): 
                    $thumbnail_url = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'arctecture-thumbnail', false); ?> 
                        <li><a href="<?php the_permalink(); ?>"><img src="<?php echo esc_url($thumbnail_url[0]); ?>" alt="" /></a></li>
                    <?php endif; ?>
            <?php } ?>
            <?php echo '</ul>';?>
        <?php } 

        wp_reset_postdata();
        wp_reset_query();

        echo wp_kses_post($args['after_widget']);
    }

    /**
     * Deals with the settings when they are saved by the admin. Here is
     * where any validation should be dealt with.
     *
     * @param array $new_instance An array of new settings as submitted by the admin
     * @param array $old_instance An array of the previous settings
     * @return array The validated and (if necessary) amended settings
     **/
    function update( $new_instance, $old_instance )
    {
        $instance = $old_instance;
        $instance['title']         = sanitize_text_field( $new_instance['title'] );
        $instance['number']        = absint( $new_instance['number'] );
        $instance['show_category']     = (bool)$new_instance['show_category'] ;
        $instance['show_date']     = (bool)$new_instance['show_date'] ;
        return $instance;
    }

    /**
     * Displays the form for this widget on the Widgets page of the WP Admin area.
     *
     * @param array $instance An array of the current settings for this widget
     * @return void Echoes it's output
     **/
    function form( $instance )
    {
        $instance = wp_parse_args( (array) $instance, array(
            'title'         => esc_html__( 'Recent Project', 'arctecture' ),
            'number'        => 4,
            'show_category'     => true,
            'show_date'     => true
        ) );

        $title         = $instance['title'] ? esc_attr( $instance['title'] ) : esc_html__( 'Recent Project', 'arctecture' );
        $number        = absint( $instance['number'] );
        $show_category     = (bool) $instance['show_category'];
        $show_date     = (bool) $instance['show_date'];

        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'arctecture' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'arctecture' ); ?></label>
            <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" value="<?php echo esc_attr( $number ); ?>" size="3" />
        </p>

        <p>
            <input class="checkbox" type="checkbox"<?php checked( $show_category ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_category' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_category' ) ); ?>" value="1" />
            <label for="<?php echo esc_attr( $this->get_field_id( 'show_category' ) ); ?>"><?php esc_html_e( 'Display portfolio category?', 'arctecture' ); ?></label>
        </p>

        <p>
            <input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_date' ) ); ?>" value="1" />
            <label for="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>"><?php esc_html_e( 'Display portfolio date?', 'arctecture' ); ?></label>
        </p>

        <?php
    }
}

function cms_recent_portfolio() {
    register_widget('CMS_Recent_Project_Widget');
}
add_action('widgets_init', 'cms_recent_portfolio'); ?>